@@ -8,12 +8,18 @@ XML::SAX::Tap - Tap a pipeline of SAX processors
 
     use XML::SAX::Machines qw( Pipeline Tap ) ;
 
-    my $d = Pipeline(
+    my $m = Pipeline(
         "UpstreamFilter",
         Tap( "My::Reformatter", \*STDERR ),
         "DownstreamFilter",
     );
 
+    my $m = Pipeline(
+        "UpstreamFilter",
+        Tap( "| xmllint --format -" ),
+        "DownstreamFilter",
+    );
+
 =head1 DESCRIPTION
 
 XML::SAX::Tap is a SAX machine that passes each event it receives on to
